;rbsp_efw_DCfield_removal_crib
;
;Subtracts off the Tsyganenko field model from GSM mag data
;
;
;Written by Aaron Breneman, UNN, Dec 2012
;		email: awbrenem@gmail.com





; initialize RBSP environment
	rbsp_efw_init
	!rbsp_efw.user_agent = ''


; set desired probe
	probe = 'a'
	rbspx = 'rbsp'+probe
	
	
; set time of interest to a single day
	date = '2012-10-13'	; UTC.
	duration = 1 ; days.
	timespan, date, duration



;misc variables
	integration=0 ; for looking at integration data
	get_support_data = 0 ; 0=no, 1=yes


	type='calibrated' ; use ADC (raw) numbers or physical (calibrated) units?



;Load spice predicted kernels. Overwrite with actual data if it exists
	rbsp_load_spice_predict
	rbsp_load_spice_kernels


	
;Load mag data (loads GEI at the moment)
	rbsp_load_emfisis,probe=probe,/quicklook  ;load this for the mag model subtract


;MANUALLY LOAD EMFISIS GEI FILE		
		;cdf_leap_second_init
		;files = '~/data/rbsp/emfisis/Flight/RBSP-A/Quick-Look/2012/10/13/rbsp-a_magnetometer_hires-gei_emfisis-Quick-Look_20121013_v1.2.1.cdf'
		;cdf2tplot,files=files
		;;Returns "Mag"
		;get_data,'Mag',data=dd,dlimits=dlim,limits=lim
		;store_data,rbspx+'_emfisis_quicklook_Mag',data=dd,dlimits=dlim,limits=lim
		


;Downsample data to spinperiod
	rbsp_downsample,[rbspx+'_emfisis_quicklook_Mag',$
					 rbspx+'_emfisis_quicklook_Magnitude'],1/11.,/nochange



;Transform to GSM
	cotrans,rbspx+'_emfisis_quicklook_Mag',rbspx+'_mag_gse',/GEI2GSE
	cotrans,rbspx+'_mag_gse',rbspx+'_mag_gsm',/GSE2GSM





;Load RBSP position data and transform to GSM which is needed for the model subtraction
	rbsp_load_spice_state,probe=probe,coord='gse',/no_spice_load  
	cotrans,rbspx+'_state_pos_gse',rbspx+'_state_pos_gsm',/GSE2GSM	







;Fill out dlimits and limits structures for position data. 
;Necessary to use THEMIS model subtraction routines
	get_data,rbspx+'_state_pos_gsm',data=pos,dlimits=dlim,limits=lim


	gatt = {project:'RBSP'}
	vatt = {tmp:'tmp'}
	
	cdf = {filename:'',$
		   gatt:gatt,$
		   vname:rbspx+'_pos',$
		   vatt:vatt}
	
	data_att = {coord_sys:'gsm',$
				st_type:'pos',$
				units:'km'}
	
	dl2 = {cdf:cdf,$
		  spec:0b,$
		  log:0b,$
		  data_att:data_att,$
		  colors:[2,4,6],$
		  labels:['x_gsm','y_gsm','z_gsm'],$
		  ysubtitle:'[km]'}
			
	store_data,rbspx+'_state_pos_gsm',data={x:pos.x,y:pos.y,v:[1,2,3]},dlimits=dl2,limits=lim





;Interpolate the mag data to the times of the position data
	tinterpol_mxn,rbspx+'_mag_gsm',pos.x,newname=rbspx+'_mag_gsm'
	




;Subtract off field model	
	model = 't96'

	magname = rbspx+'_mag_gsm'
	posname = rbspx+'_state_pos_gsm'
	rbsp_subtract_dcfield,magname,posname,probe,model=model







;Set plot options
	tplot_options,'xmargin',[20.,15.]
	tplot_options,'ymargin',[3,6]
	tplot_options,'xticklen',0.08
	tplot_options,'yticklen',0.02
	tplot_options,'xthick',2
	tplot_options,'ythick',2
	tplot_options,'labflag',-1	



;Plot various quantities

	ylim,[magname,$
		  magname + '_' + model + '_dif',$
		  magname + '_' + model + '_wind_dif',$
		  magname + '_' + model + '_ace_dif',$
		  magname + '_' + model + '_omni_dif',$
		  magname + '_' + model,$
		  magname + '_' + model + '_wind',$
		  magname + '_' + model + '_ace',$
		  magname + '_' + model + '_omni'],-2d4,2d4


	tplot_options,'title','Mag model comparison'
	tplot,[magname,$
		   magname + '_' + model,$
		   magname + '_' + model + '_dif']

	tplot_options,'title','Mag model comparison using Wind data'
	tplot,[magname,$
		   magname + '_' + model + '_wind',$
		   magname + '_' + model + '_wind_dif']

	tplot_options,'title','Mag model comparison using ACE data'
	tplot,[magname,$
		   magname + '_' + model + '_ace',$
		   magname + '_' + model + '_ace_dif']

	tplot_options,'title','Mag model comparison using OMNI data'
	tplot,[magname,$
		   magname + '_' + model + '_omni',$
		   magname + '_' + model + '_omni_dif']





;Plot with zoomed in yscale
	ylim,[magname,$
		  magname + '_' + model + '_dif',$
		  magname + '_' + model + '_wind_dif',$
		  magname + '_' + model + '_ace_dif',$
		  magname + '_' + model + '_omni_dif',$
		  magname + '_' + model,$
		  magname + '_' + model + '_wind',$
		  magname + '_' + model + '_ace',$
		  magname + '_' + model + '_omni'],-200,200


	tplot_options,'title','Mag model comparison'
	tplot,[magname,$
		   magname + '_' + model,$
		   magname + '_' + model + '_dif']

	tplot_options,'title','Mag model comparison using Wind data'
	tplot,[magname,$
		   magname + '_' + model + '_wind',$
		   magname + '_' + model + '_wind_dif']

	tplot_options,'title','Mag model comparison using ACE data'
	tplot,[magname,$
		   magname + '_' + model + '_ace',$
		   magname + '_' + model + '_ace_dif']

	tplot_options,'title','Mag model comparison using OMNI data'
	tplot,[magname,$
		   magname + '_' + model + '_omni',$
		   magname + '_' + model + '_omni_dif']






;compare the four models

	ylim,[magname + '_' + model + '_dif',$
		   magname + '_' + model + '_wind_dif',$
		   magname + '_' + model + '_ace_dif',$
		   magname + '_' + model + '_omni_dif'],-100,100


	tplot,[magname + '_' + model + '_dif',$
		   magname + '_' + model + '_wind_dif',$
		   magname + '_' + model + '_ace_dif',$
		   magname + '_' + model + '_omni_dif']
		
	
	
	
	
