;Downsample tplot quantities
;
;
;tname = name of tplot quantity. Can be a size [n] or [n,x]
;sr = new sample rate (S/sec)
;nochange - set if you'd like to overwrite the original tplot variable name
;			Otherwise newname = oldname + '_DS'
;suffix = appended to end of tname. Defaults to 'tname_DS'
;
;
;
;Created by Aaron Breneman  10-29-2012
;	Modified: 2012-12-11 : Added anti-aliasing filter

pro rbsp_downsample,tnames,sr,nochange=nochange,suffix=suffix

if ~keyword_set(suffix) then suffix = '_DS'
if ~keyword_set(sr) then sr=1


for j=0,n_elements(tnames)-1 do begin
	get_data,tnames[j],data=dat,dlimits=dlim,limits=lim
	
	if is_struct(dat) then begin


		;get new times at cadence of "sr"		
		t0 = min(dat.x)
		t1 = max(dat.x)
		newt = dindgen((t1-t0)*sr)/sr + t0
	
		;Test to see if variable is a [n] or [n,x] element array
		tst = size(dat.y,/n_dimensions)
		tst2 = size(dat.y,/dimensions)


		;new Nyquist freq after downsampling will be:
		nyq_new = sr/2.

		;time b/t samples
		dt = dat.x[1]-dat.x[0]


		N = n_elements(dat.x)
		num = lindgen(n_elements(dat.x)/2.)

		;Current range of frequencies in signal is:			
		fcurrent = num/(N*dt)

		;Freqs that will result in aliasing
		badfreqs = where(fcurrent gt nyq_new)


		if tst eq 1 then begin
		
		
			;Bandpass original signal to keep freqs only at or below
			;this new Nyquist freq
						
			tmp = fft(dat.y)

			;Remove freqs that will be aliased
			if badfreqs[0] ne -1 then tmp[badfreqs] = 0.
			newsignal = fft(tmp,1)
		
			;Interpolate to lower sample rate
			dat2 = interpol(newsignal,dat.x,newt)
		
		
		endif

		


		
		if tst gt 1 then begin					

			dat2 = reform(dblarr(n_elements(newt),tst2[1]))	

			for b=0,tst2[1]-1 do begin


				;Bandpass original signal to keep freqs only at or below
				;this new Nyquist freq
				
				tmp = fft(dat.y[*,b])
	
				;Remove freqs that will be aliased
				if badfreqs[0] ne -1 then tmp[badfreqs] = 0.
				newsignal = fft(tmp,1)
		
		
			
				;Interpolate to lower sample rate
				dat2[*,b] = interpol(newsignal,dat.x,newt)
		

			endfor
		endif	
		
		

		
		if ~keyword_set(nochange) then store_data,tnames[j]+suffix,data={x:newt,y:dat2},dlimits=dlim,limits=lim $
		else store_data,tnames[j],data={x:newt,y:dat2},dlimits=dlim,limits=lim
		
	endif

endfor


end

